Class: USCoreTestKit::Generator::GroupMetadataExtractor
- Inherits:
-
Object
- Object
- USCoreTestKit::Generator::GroupMetadataExtractor
- Defined in:
- lib/us_core_test_kit/generator/group_metadata_extractor.rb
Instance Attribute Summary collapse
-
#ig_metadata ⇒ Object
Returns the value of attribute ig_metadata.
-
#ig_resources ⇒ Object
Returns the value of attribute ig_resources.
-
#profile_url ⇒ Object
Returns the value of attribute profile_url.
-
#resource_capabilities ⇒ Object
Returns the value of attribute resource_capabilities.
Instance Method Summary collapse
- #base_name ⇒ Object
- #bindings ⇒ Object
-
#category_first_profile? ⇒ Boolean
BEGIN SPECIAL CASES ###.
- #class_name ⇒ Object
- #first_search_params ⇒ Object
- #group_metadata ⇒ Object
- #group_metadata_hash ⇒ Object
- #handle_special_cases ⇒ Object
- #include_params ⇒ Object
-
#initialize(resource_capabilities, profile_url, ig_metadata, ig_resources) ⇒ GroupMetadataExtractor
constructor
A new instance of GroupMetadataExtractor.
- #interactions ⇒ Object
- #mandatory_elements ⇒ Object
- #mark_mandatory_and_must_support_searches ⇒ Object
- #must_support_metadata_extractor ⇒ Object
- #must_supports ⇒ Object
- #name ⇒ Object
- #operations ⇒ Object
-
#profile ⇒ Object
END SPECIAL CASES ###.
- #profile_elements ⇒ Object
- #profile_name ⇒ Object
- #profile_version ⇒ Object
- #references ⇒ Object
- #reformatted_version ⇒ Object
- #required_concepts ⇒ Object
- #resource ⇒ Object
- #resource_conformance_expectation ⇒ Object
- #revincludes ⇒ Object
- #search_definitions ⇒ Object
- #search_metadata_extractor ⇒ Object
- #searches ⇒ Object
- #set_first_search ⇒ Object
- #short_description ⇒ Object
- #terminology_binding_metadata_extractor ⇒ Object
- #title ⇒ Object
- #version ⇒ Object
Constructor Details
#initialize(resource_capabilities, profile_url, ig_metadata, ig_resources) ⇒ GroupMetadataExtractor
Returns a new instance of GroupMetadataExtractor.
13 14 15 16 17 18 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 13 def initialize(resource_capabilities, profile_url, , ig_resources) self.resource_capabilities = resource_capabilities self.profile_url = profile_url self. = self.ig_resources = ig_resources end |
Instance Attribute Details
#ig_metadata ⇒ Object
Returns the value of attribute ig_metadata.
11 12 13 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 11 def @ig_metadata end |
#ig_resources ⇒ Object
Returns the value of attribute ig_resources.
11 12 13 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 11 def ig_resources @ig_resources end |
#profile_url ⇒ Object
Returns the value of attribute profile_url.
11 12 13 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 11 def profile_url @profile_url end |
#resource_capabilities ⇒ Object
Returns the value of attribute resource_capabilities.
11 12 13 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 11 def resource_capabilities @resource_capabilities end |
Instance Method Details
#base_name ⇒ Object
141 142 143 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 141 def base_name profile_url.split('StructureDefinition/').last end |
#bindings ⇒ Object
258 259 260 261 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 258 def bindings @bindings ||= .terminology_bindings end |
#category_first_profile? ⇒ Boolean
BEGIN SPECIAL CASES ###
99 100 101 102 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 99 def category_first_profile? SpecialCases::ALL_VERSION_CATEGORY_FIRST_PROFILES.include?(profile_url) || SpecialCases::VERSION_SPECIFIC_CATEGORY_FIRST_PROFILES[profile_url]&.include?(reformatted_version) end |
#class_name ⇒ Object
149 150 151 152 153 154 155 156 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 149 def class_name base_name .split('-') .map(&:capitalize) .join .gsub('UsCore', "USCore#{.reformatted_version}") .concat('Sequence') end |
#first_search_params ⇒ Object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 104 def first_search_params @first_search_params ||= if category_first_profile? ['patient', 'category'] elsif resource == 'Observation' ['patient', 'code'] elsif resource == 'MedicationRequest' ['patient', 'intent'] elsif resource == 'CareTeam' ['patient', 'status'] else ['patient'] end end |
#group_metadata ⇒ Object
20 21 22 23 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 20 def @group_metadata ||= GroupMetadata.new() end |
#group_metadata_hash ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 25 def @group_metadata_hash ||= { name: name, class_name: class_name, version: version, reformatted_version: reformatted_version, # test_id_prefix: test_id_prefix, resource: resource, profile_url: profile_url, profile_name: profile_name, profile_version: profile_version, title: title, short_description: short_description, interactions: interactions, operations: operations, searches: searches, search_definitions: search_definitions, include_params: include_params, revincludes: revincludes, required_concepts: required_concepts, must_supports: must_supports, mandatory_elements: mandatory_elements, bindings: bindings, references: references, resource_conformance_expectation: resource_conformance_expectation # tests: [] } mark_mandatory_and_must_support_searches handle_special_cases @group_metadata_hash end |
#handle_special_cases ⇒ Object
119 120 121 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 119 def handle_special_cases set_first_search end |
#include_params ⇒ Object
233 234 235 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 233 def include_params resource_capabilities.searchInclude || [] end |
#interactions ⇒ Object
192 193 194 195 196 197 198 199 200 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 192 def interactions @interactions ||= resource_capabilities.interaction.map do |interaction| { code: interaction.code, expectation: interaction.extension.first.valueCode # TODO: fix expectation extension finding } end end |
#mandatory_elements ⇒ Object
273 274 275 276 277 278 279 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 273 def mandatory_elements @mandatory_elements ||= profile_elements .select { |element| element.min.positive? } .map { |element| element.path } .uniq end |
#mark_mandatory_and_must_support_searches ⇒ Object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 60 def mark_mandatory_and_must_support_searches searches.each do |search| search[:names_not_must_support_or_mandatory] = search[:names].reject do |name| full_paths = search_definitions[name.to_sym][:full_paths] any_must_support_elements = (must_supports[:elements]).any? do |element| full_must_support_paths = ["#{resource}.#{element[:original_path]}", "#{resource}.#{element[:path]}"] full_paths.any? do |path| # allow for non-choice, choice types, and _id name == '_id' || full_must_support_paths.include?(path) || full_must_support_paths.include?("#{path}[x]") end end any_must_support_slices = must_supports[:slices].any? do |slice| # only handle type slices because that is all we need for now # for a slice like Observation.effective[x]:effectiveDateTime, the search parameter's expression could be # either Observation.effective or Observation.effectiveDateTime. if slice[:discriminator] && slice[:discriminator][:type] == 'type' full_must_support_path = "#{resource}.#{slice[:path].sub('[x]', slice[:discriminator][:code])}" base_must_support_path = "#{resource}.#{slice[:path].sub('[x]', '')}" full_paths.intersection([full_must_support_path,base_must_support_path]).present? else false end end any_mandatory_elements = mandatory_elements.any? do |element| full_paths.include?(element) end any_must_support_elements || any_must_support_slices || any_mandatory_elements end search[:must_support_or_mandatory] = search[:names_not_must_support_or_mandatory].empty? end end |
#must_support_metadata_extractor ⇒ Object
263 264 265 266 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 263 def @must_support_metadata_extractor ||= MustSupportMetadataExtractor.new(profile_elements, profile, resource, ig_resources) end |
#must_supports ⇒ Object
268 269 270 271 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 268 def must_supports @must_supports ||= .must_supports end |
#name ⇒ Object
145 146 147 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 145 def name base_name.tr('-', '_') end |
#operations ⇒ Object
202 203 204 205 206 207 208 209 210 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 202 def operations @operations ||= resource_capabilities.operation.map do |operation| { code: operation.name, expectation: operation.extension.first.valueCode # TODO: fix expectation extension finding } end end |
#profile ⇒ Object
END SPECIAL CASES ###
133 134 135 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 133 def profile @profile ||= ig_resources.profile_by_url(profile_url) end |
#profile_elements ⇒ Object
137 138 139 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 137 def profile_elements @profile_elements ||= profile.snapshot.element end |
#profile_name ⇒ Object
170 171 172 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 170 def profile_name profile.title.gsub(' ', ' ') end |
#profile_version ⇒ Object
174 175 176 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 174 def profile_version profile.version end |
#references ⇒ Object
281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 281 def references @references ||= profile_elements .select { |element| element.type&.first&.code == 'Reference' } .map do |reference_definition| { path: reference_definition.path, profiles: reference_definition.type.first.targetProfile } end end |
#reformatted_version ⇒ Object
162 163 164 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 162 def reformatted_version .reformatted_version end |
#required_concepts ⇒ Object
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 241 def required_concepts # The base FHIR vital signs profile has a required binding that isn't # relevant for any of its child profiles return [] if resource == 'Observation' profile_elements .select { |element| element.type&.any? { |type| type.code == 'CodeableConcept' } } .select { |element| element.binding&.strength == 'required' } .map { |element| element.path.gsub("#{resource}.", '').gsub('[x]', 'CodeableConcept') } .uniq end |
#resource ⇒ Object
166 167 168 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 166 def resource resource_capabilities.type end |
#resource_conformance_expectation ⇒ Object
293 294 295 296 297 298 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 293 def resource_conformance_expectation @resource_conformance_expectation ||= resource_capabilities.extension.find do |extension| extension.url == 'http://hl7.org/fhir/StructureDefinition/capabilitystatement-expectation' end&.valueCode end |
#revincludes ⇒ Object
237 238 239 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 237 def revincludes resource_capabilities.searchRevInclude || [] end |
#search_definitions ⇒ Object
229 230 231 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 229 def search_definitions @search_definitions ||= .search_definitions end |
#search_metadata_extractor ⇒ Object
212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 212 def @search_metadata_extractor ||= SearchMetadataExtractor.new( resource_capabilities, ig_resources, profile_elements, { resource: resource, profile_url: profile_url, must_supports: must_supports } ) end |
#searches ⇒ Object
225 226 227 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 225 def searches @searches ||= .searches end |
#set_first_search ⇒ Object
123 124 125 126 127 128 129 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 123 def set_first_search search = searches.find { |param| param[:names] == first_search_params } return if search.nil? searches.delete(search) searches.unshift(search) end |
#short_description ⇒ Object
188 189 190 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 188 def short_description "Verify support for the server capabilities required by the #{profile_name}." end |
#terminology_binding_metadata_extractor ⇒ Object
253 254 255 256 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 253 def @terminology_binding_metadata_extractor ||= TerminologyBindingMetadataExtractor.new(profile_elements, ig_resources, resource) end |
#title ⇒ Object
178 179 180 181 182 183 184 185 186 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 178 def title title = profile.title.gsub(/US\s*Core\s*/, '').gsub(/\s*Profile/, '').strip if (Naming.resources_with_multiple_profiles.include?(resource)) && !title.start_with?(resource) && version != 'v3.1.1' title = resource + ' ' + title.split(resource).map(&:strip).join(' ') end title end |
#version ⇒ Object
158 159 160 |
# File 'lib/us_core_test_kit/generator/group_metadata_extractor.rb', line 158 def version .ig_version end |