Module: USCoreTestKit::SearchTest

Extended by:
Forwardable
Includes:
DateSearchValidation, FHIRResourceNavigation
Included in:
ClinicalNoteTypeTest, USCoreV311::AllergyIntolerancePatientClinicalStatusSearchTest, USCoreV311::AllergyIntolerancePatientSearchTest, USCoreV311::AllergyIntoleranceProvenanceRevincludeSearchTest, USCoreV311::BodyheightPatientCategoryDateSearchTest, USCoreV311::BodyheightPatientCategorySearchTest, USCoreV311::BodyheightPatientCategoryStatusSearchTest, USCoreV311::BodyheightPatientCodeDateSearchTest, USCoreV311::BodyheightPatientCodeSearchTest, USCoreV311::BodyheightProvenanceRevincludeSearchTest, USCoreV311::BodytempPatientCategoryDateSearchTest, USCoreV311::BodytempPatientCategorySearchTest, USCoreV311::BodytempPatientCategoryStatusSearchTest, USCoreV311::BodytempPatientCodeDateSearchTest, USCoreV311::BodytempPatientCodeSearchTest, USCoreV311::BodytempProvenanceRevincludeSearchTest, USCoreV311::BodyweightPatientCategoryDateSearchTest, USCoreV311::BodyweightPatientCategorySearchTest, USCoreV311::BodyweightPatientCategoryStatusSearchTest, USCoreV311::BodyweightPatientCodeDateSearchTest, USCoreV311::BodyweightPatientCodeSearchTest, USCoreV311::BodyweightProvenanceRevincludeSearchTest, USCoreV311::BpPatientCategoryDateSearchTest, USCoreV311::BpPatientCategorySearchTest, USCoreV311::BpPatientCategoryStatusSearchTest, USCoreV311::BpPatientCodeDateSearchTest, USCoreV311::BpPatientCodeSearchTest, USCoreV311::BpProvenanceRevincludeSearchTest, USCoreV311::CarePlanPatientCategoryDateSearchTest, USCoreV311::CarePlanPatientCategorySearchTest, USCoreV311::CarePlanPatientCategoryStatusDateSearchTest, USCoreV311::CarePlanPatientCategoryStatusSearchTest, USCoreV311::CarePlanProvenanceRevincludeSearchTest, USCoreV311::CareTeamPatientStatusSearchTest, USCoreV311::CareTeamProvenanceRevincludeSearchTest, USCoreV311::ConditionPatientCategorySearchTest, USCoreV311::ConditionPatientClinicalStatusSearchTest, USCoreV311::ConditionPatientCodeSearchTest, USCoreV311::ConditionPatientOnsetDateSearchTest, USCoreV311::ConditionPatientSearchTest, USCoreV311::ConditionProvenanceRevincludeSearchTest, USCoreV311::DevicePatientSearchTest, USCoreV311::DevicePatientTypeSearchTest, USCoreV311::DeviceProvenanceRevincludeSearchTest, USCoreV311::DiagnosticReportLabPatientCategoryDateSearchTest, USCoreV311::DiagnosticReportLabPatientCategorySearchTest, USCoreV311::DiagnosticReportLabPatientCodeDateSearchTest, USCoreV311::DiagnosticReportLabPatientCodeSearchTest, USCoreV311::DiagnosticReportLabPatientSearchTest, USCoreV311::DiagnosticReportLabPatientStatusSearchTest, USCoreV311::DiagnosticReportLabProvenanceRevincludeSearchTest, USCoreV311::DiagnosticReportNotePatientCategoryDateSearchTest, USCoreV311::DiagnosticReportNotePatientCategorySearchTest, USCoreV311::DiagnosticReportNotePatientCodeDateSearchTest, USCoreV311::DiagnosticReportNotePatientCodeSearchTest, USCoreV311::DiagnosticReportNotePatientSearchTest, USCoreV311::DiagnosticReportNotePatientStatusSearchTest, USCoreV311::DiagnosticReportNoteProvenanceRevincludeSearchTest, USCoreV311::DocumentReferenceIdSearchTest, USCoreV311::DocumentReferencePatientCategoryDateSearchTest, USCoreV311::DocumentReferencePatientCategorySearchTest, USCoreV311::DocumentReferencePatientSearchTest, USCoreV311::DocumentReferencePatientStatusSearchTest, USCoreV311::DocumentReferencePatientTypePeriodSearchTest, USCoreV311::DocumentReferencePatientTypeSearchTest, USCoreV311::DocumentReferenceProvenanceRevincludeSearchTest, USCoreV311::EncounterClassPatientSearchTest, USCoreV311::EncounterDatePatientSearchTest, USCoreV311::EncounterIdSearchTest, USCoreV311::EncounterIdentifierSearchTest, USCoreV311::EncounterPatientSearchTest, USCoreV311::EncounterPatientStatusSearchTest, USCoreV311::EncounterPatientTypeSearchTest, USCoreV311::EncounterProvenanceRevincludeSearchTest, USCoreV311::GoalPatientLifecycleStatusSearchTest, USCoreV311::GoalPatientSearchTest, USCoreV311::GoalPatientTargetDateSearchTest, USCoreV311::GoalProvenanceRevincludeSearchTest, USCoreV311::HeadCircumferencePatientCategoryDateSearchTest, USCoreV311::HeadCircumferencePatientCategorySearchTest, USCoreV311::HeadCircumferencePatientCategoryStatusSearchTest, USCoreV311::HeadCircumferencePatientCodeDateSearchTest, USCoreV311::HeadCircumferencePatientCodeSearchTest, USCoreV311::HeadCircumferenceProvenanceRevincludeSearchTest, USCoreV311::HeartratePatientCategoryDateSearchTest, USCoreV311::HeartratePatientCategorySearchTest, USCoreV311::HeartratePatientCategoryStatusSearchTest, USCoreV311::HeartratePatientCodeDateSearchTest, USCoreV311::HeartratePatientCodeSearchTest, USCoreV311::HeartrateProvenanceRevincludeSearchTest, USCoreV311::ImmunizationPatientDateSearchTest, USCoreV311::ImmunizationPatientSearchTest, USCoreV311::ImmunizationPatientStatusSearchTest, USCoreV311::ImmunizationProvenanceRevincludeSearchTest, USCoreV311::MedicationRequestPatientIntentAuthoredonSearchTest, USCoreV311::MedicationRequestPatientIntentEncounterSearchTest, USCoreV311::MedicationRequestPatientIntentSearchTest, USCoreV311::MedicationRequestPatientIntentStatusSearchTest, USCoreV311::MedicationRequestProvenanceRevincludeSearchTest, USCoreV311::ObservationLabPatientCategoryDateSearchTest, USCoreV311::ObservationLabPatientCategorySearchTest, USCoreV311::ObservationLabPatientCategoryStatusSearchTest, USCoreV311::ObservationLabPatientCodeDateSearchTest, USCoreV311::ObservationLabPatientCodeSearchTest, USCoreV311::ObservationLabProvenanceRevincludeSearchTest, USCoreV311::OrganizationAddressSearchTest, USCoreV311::OrganizationNameSearchTest, USCoreV311::PatientBirthdateFamilySearchTest, USCoreV311::PatientBirthdateNameSearchTest, USCoreV311::PatientFamilyGenderSearchTest, USCoreV311::PatientGenderNameSearchTest, USCoreV311::PatientIdSearchTest, USCoreV311::PatientIdentifierSearchTest, USCoreV311::PatientNameSearchTest, USCoreV311::PatientProvenanceRevincludeSearchTest, USCoreV311::PediatricBmiForAgePatientCategoryDateSearchTest, USCoreV311::PediatricBmiForAgePatientCategorySearchTest, USCoreV311::PediatricBmiForAgePatientCategoryStatusSearchTest, USCoreV311::PediatricBmiForAgePatientCodeDateSearchTest, USCoreV311::PediatricBmiForAgePatientCodeSearchTest, USCoreV311::PediatricBmiForAgeProvenanceRevincludeSearchTest, USCoreV311::PediatricWeightForHeightPatientCategoryDateSearchTest, USCoreV311::PediatricWeightForHeightPatientCategorySearchTest, USCoreV311::PediatricWeightForHeightPatientCategoryStatusSearchTest, USCoreV311::PediatricWeightForHeightPatientCodeDateSearchTest, USCoreV311::PediatricWeightForHeightPatientCodeSearchTest, USCoreV311::PediatricWeightForHeightProvenanceRevincludeSearchTest, USCoreV311::PractitionerIdentifierSearchTest, USCoreV311::PractitionerNameSearchTest, USCoreV311::ProcedurePatientCodeDateSearchTest, USCoreV311::ProcedurePatientDateSearchTest, USCoreV311::ProcedurePatientSearchTest, USCoreV311::ProcedurePatientStatusSearchTest, USCoreV311::ProcedureProvenanceRevincludeSearchTest, USCoreV311::PulseOximetryPatientCategoryDateSearchTest, USCoreV311::PulseOximetryPatientCategorySearchTest, USCoreV311::PulseOximetryPatientCategoryStatusSearchTest, USCoreV311::PulseOximetryPatientCodeDateSearchTest, USCoreV311::PulseOximetryPatientCodeSearchTest, USCoreV311::PulseOximetryProvenanceRevincludeSearchTest, USCoreV311::RespratePatientCategoryDateSearchTest, USCoreV311::RespratePatientCategorySearchTest, USCoreV311::RespratePatientCategoryStatusSearchTest, USCoreV311::RespratePatientCodeDateSearchTest, USCoreV311::RespratePatientCodeSearchTest, USCoreV311::ResprateProvenanceRevincludeSearchTest, USCoreV311::SmokingstatusPatientCategoryDateSearchTest, USCoreV311::SmokingstatusPatientCategorySearchTest, USCoreV311::SmokingstatusPatientCategoryStatusSearchTest, USCoreV311::SmokingstatusPatientCodeDateSearchTest, USCoreV311::SmokingstatusPatientCodeSearchTest, USCoreV311::SmokingstatusProvenanceRevincludeSearchTest, USCoreV400::AllergyIntolerancePatientClinicalStatusSearchTest, USCoreV400::AllergyIntolerancePatientSearchTest, USCoreV400::AllergyIntoleranceProvenanceRevincludeSearchTest, USCoreV400::BloodPressurePatientCategoryDateSearchTest, USCoreV400::BloodPressurePatientCategorySearchTest, USCoreV400::BloodPressurePatientCategoryStatusSearchTest, USCoreV400::BloodPressurePatientCodeDateSearchTest, USCoreV400::BloodPressurePatientCodeSearchTest, USCoreV400::BloodPressureProvenanceRevincludeSearchTest, USCoreV400::BmiPatientCategoryDateSearchTest, USCoreV400::BmiPatientCategorySearchTest, USCoreV400::BmiPatientCategoryStatusSearchTest, USCoreV400::BmiPatientCodeDateSearchTest, USCoreV400::BmiPatientCodeSearchTest, USCoreV400::BmiProvenanceRevincludeSearchTest, USCoreV400::BodyHeightPatientCategoryDateSearchTest, USCoreV400::BodyHeightPatientCategorySearchTest, USCoreV400::BodyHeightPatientCategoryStatusSearchTest, USCoreV400::BodyHeightPatientCodeDateSearchTest, USCoreV400::BodyHeightPatientCodeSearchTest, USCoreV400::BodyHeightProvenanceRevincludeSearchTest, USCoreV400::BodyTemperaturePatientCategoryDateSearchTest, USCoreV400::BodyTemperaturePatientCategorySearchTest, USCoreV400::BodyTemperaturePatientCategoryStatusSearchTest, USCoreV400::BodyTemperaturePatientCodeDateSearchTest, USCoreV400::BodyTemperaturePatientCodeSearchTest, USCoreV400::BodyTemperatureProvenanceRevincludeSearchTest, USCoreV400::BodyWeightPatientCategoryDateSearchTest, USCoreV400::BodyWeightPatientCategorySearchTest, USCoreV400::BodyWeightPatientCategoryStatusSearchTest, USCoreV400::BodyWeightPatientCodeDateSearchTest, USCoreV400::BodyWeightPatientCodeSearchTest, USCoreV400::BodyWeightProvenanceRevincludeSearchTest, USCoreV400::CarePlanPatientCategoryDateSearchTest, USCoreV400::CarePlanPatientCategorySearchTest, USCoreV400::CarePlanPatientCategoryStatusDateSearchTest, USCoreV400::CarePlanPatientCategoryStatusSearchTest, USCoreV400::CarePlanProvenanceRevincludeSearchTest, USCoreV400::CareTeamPatientStatusSearchTest, USCoreV400::CareTeamProvenanceRevincludeSearchTest, USCoreV400::ConditionPatientCategorySearchTest, USCoreV400::ConditionPatientClinicalStatusSearchTest, USCoreV400::ConditionPatientCodeSearchTest, USCoreV400::ConditionPatientOnsetDateSearchTest, USCoreV400::ConditionPatientSearchTest, USCoreV400::ConditionProvenanceRevincludeSearchTest, USCoreV400::DevicePatientSearchTest, USCoreV400::DevicePatientTypeSearchTest, USCoreV400::DeviceProvenanceRevincludeSearchTest, USCoreV400::DiagnosticReportLabPatientCategoryDateSearchTest, USCoreV400::DiagnosticReportLabPatientCategorySearchTest, USCoreV400::DiagnosticReportLabPatientCodeDateSearchTest, USCoreV400::DiagnosticReportLabPatientCodeSearchTest, USCoreV400::DiagnosticReportLabPatientSearchTest, USCoreV400::DiagnosticReportLabPatientStatusSearchTest, USCoreV400::DiagnosticReportLabProvenanceRevincludeSearchTest, USCoreV400::DiagnosticReportNotePatientCategoryDateSearchTest, USCoreV400::DiagnosticReportNotePatientCategorySearchTest, USCoreV400::DiagnosticReportNotePatientCodeDateSearchTest, USCoreV400::DiagnosticReportNotePatientCodeSearchTest, USCoreV400::DiagnosticReportNotePatientSearchTest, USCoreV400::DiagnosticReportNotePatientStatusSearchTest, USCoreV400::DiagnosticReportNoteProvenanceRevincludeSearchTest, USCoreV400::DocumentReferenceIdSearchTest, USCoreV400::DocumentReferencePatientCategoryDateSearchTest, USCoreV400::DocumentReferencePatientCategorySearchTest, USCoreV400::DocumentReferencePatientSearchTest, USCoreV400::DocumentReferencePatientStatusSearchTest, USCoreV400::DocumentReferencePatientTypePeriodSearchTest, USCoreV400::DocumentReferencePatientTypeSearchTest, USCoreV400::DocumentReferenceProvenanceRevincludeSearchTest, USCoreV400::EncounterClassPatientSearchTest, USCoreV400::EncounterDatePatientSearchTest, USCoreV400::EncounterIdSearchTest, USCoreV400::EncounterIdentifierSearchTest, USCoreV400::EncounterPatientSearchTest, USCoreV400::EncounterPatientStatusSearchTest, USCoreV400::EncounterPatientTypeSearchTest, USCoreV400::EncounterProvenanceRevincludeSearchTest, USCoreV400::GoalPatientLifecycleStatusSearchTest, USCoreV400::GoalPatientSearchTest, USCoreV400::GoalPatientTargetDateSearchTest, USCoreV400::GoalProvenanceRevincludeSearchTest, USCoreV400::HeadCircumferencePatientCategoryDateSearchTest, USCoreV400::HeadCircumferencePatientCategorySearchTest, USCoreV400::HeadCircumferencePatientCategoryStatusSearchTest, USCoreV400::HeadCircumferencePatientCodeDateSearchTest, USCoreV400::HeadCircumferencePatientCodeSearchTest, USCoreV400::HeadCircumferencePercentilePatientCategoryDateSearchTest, USCoreV400::HeadCircumferencePercentilePatientCategorySearchTest, USCoreV400::HeadCircumferencePercentilePatientCategoryStatusSearchTest, USCoreV400::HeadCircumferencePercentilePatientCodeDateSearchTest, USCoreV400::HeadCircumferencePercentilePatientCodeSearchTest, USCoreV400::HeadCircumferencePercentileProvenanceRevincludeSearchTest, USCoreV400::HeadCircumferenceProvenanceRevincludeSearchTest, USCoreV400::HeartRatePatientCategoryDateSearchTest, USCoreV400::HeartRatePatientCategorySearchTest, USCoreV400::HeartRatePatientCategoryStatusSearchTest, USCoreV400::HeartRatePatientCodeDateSearchTest, USCoreV400::HeartRatePatientCodeSearchTest, USCoreV400::HeartRateProvenanceRevincludeSearchTest, USCoreV400::ImmunizationPatientDateSearchTest, USCoreV400::ImmunizationPatientSearchTest, USCoreV400::ImmunizationPatientStatusSearchTest, USCoreV400::ImmunizationProvenanceRevincludeSearchTest, USCoreV400::MedicationRequestPatientIntentAuthoredonSearchTest, USCoreV400::MedicationRequestPatientIntentEncounterSearchTest, USCoreV400::MedicationRequestPatientIntentSearchTest, USCoreV400::MedicationRequestPatientIntentStatusSearchTest, USCoreV400::MedicationRequestProvenanceRevincludeSearchTest, USCoreV400::ObservationLabPatientCategoryDateSearchTest, USCoreV400::ObservationLabPatientCategorySearchTest, USCoreV400::ObservationLabPatientCategoryStatusSearchTest, USCoreV400::ObservationLabPatientCodeDateSearchTest, USCoreV400::ObservationLabPatientCodeSearchTest, USCoreV400::ObservationLabProvenanceRevincludeSearchTest, USCoreV400::OrganizationAddressSearchTest, USCoreV400::OrganizationNameSearchTest, USCoreV400::PatientBirthdateFamilySearchTest, USCoreV400::PatientBirthdateNameSearchTest, USCoreV400::PatientFamilyGenderSearchTest, USCoreV400::PatientGenderNameSearchTest, USCoreV400::PatientIdSearchTest, USCoreV400::PatientIdentifierSearchTest, USCoreV400::PatientNameSearchTest, USCoreV400::PatientProvenanceRevincludeSearchTest, USCoreV400::PediatricBmiForAgePatientCategoryDateSearchTest, USCoreV400::PediatricBmiForAgePatientCategorySearchTest, USCoreV400::PediatricBmiForAgePatientCategoryStatusSearchTest, USCoreV400::PediatricBmiForAgePatientCodeDateSearchTest, USCoreV400::PediatricBmiForAgePatientCodeSearchTest, USCoreV400::PediatricBmiForAgeProvenanceRevincludeSearchTest, USCoreV400::PediatricWeightForHeightPatientCategoryDateSearchTest, USCoreV400::PediatricWeightForHeightPatientCategorySearchTest, USCoreV400::PediatricWeightForHeightPatientCategoryStatusSearchTest, USCoreV400::PediatricWeightForHeightPatientCodeDateSearchTest, USCoreV400::PediatricWeightForHeightPatientCodeSearchTest, USCoreV400::PediatricWeightForHeightProvenanceRevincludeSearchTest, USCoreV400::PractitionerIdentifierSearchTest, USCoreV400::PractitionerNameSearchTest, USCoreV400::ProcedurePatientCodeDateSearchTest, USCoreV400::ProcedurePatientDateSearchTest, USCoreV400::ProcedurePatientSearchTest, USCoreV400::ProcedurePatientStatusSearchTest, USCoreV400::ProcedureProvenanceRevincludeSearchTest, USCoreV400::PulseOximetryPatientCategoryDateSearchTest, USCoreV400::PulseOximetryPatientCategorySearchTest, USCoreV400::PulseOximetryPatientCategoryStatusSearchTest, USCoreV400::PulseOximetryPatientCodeDateSearchTest, USCoreV400::PulseOximetryPatientCodeSearchTest, USCoreV400::PulseOximetryProvenanceRevincludeSearchTest, USCoreV400::RespiratoryRatePatientCategoryDateSearchTest, USCoreV400::RespiratoryRatePatientCategorySearchTest, USCoreV400::RespiratoryRatePatientCategoryStatusSearchTest, USCoreV400::RespiratoryRatePatientCodeDateSearchTest, USCoreV400::RespiratoryRatePatientCodeSearchTest, USCoreV400::RespiratoryRateProvenanceRevincludeSearchTest, USCoreV400::SmokingstatusPatientCategoryDateSearchTest, USCoreV400::SmokingstatusPatientCategorySearchTest, USCoreV400::SmokingstatusPatientCategoryStatusSearchTest, USCoreV400::SmokingstatusPatientCodeDateSearchTest, USCoreV400::SmokingstatusPatientCodeSearchTest, USCoreV400::SmokingstatusProvenanceRevincludeSearchTest
Defined in:
lib/us_core_test_kit/search_test.rb

Instance Method Summary collapse

Methods included from FHIRResourceNavigation

#find_a_value_at, #get_next_value, #resolve_path

Methods included from DateSearchValidation

#fhir_date_comparer, #get_fhir_datetime_range, #get_fhir_period_range, #validate_date_search, #validate_datetime_search, #validate_period_search

Instance Method Details

#all_comparator_searches_tested?Boolean

Returns:

  • (Boolean)


189
190
191
192
193
# File 'lib/us_core_test_kit/search_test.rb', line 189

def all_comparator_searches_tested?
  return true if params_with_comparators.blank?

  Set.new(params_with_comparators) == search_variant_test_records[:comparator_searches]
end

#all_provenance_revinclude_search_paramsObject



44
45
46
47
48
49
# File 'lib/us_core_test_kit/search_test.rb', line 44

def all_provenance_revinclude_search_params
  @all_provenance_revinclude_search_params ||=
    all_search_params.transform_values! do |params_list|
      params_list.map { |params| params.merge(_revinclude: 'Provenance:target') }
    end
end

#all_scratch_resourcesObject



397
398
399
# File 'lib/us_core_test_kit/search_test.rb', line 397

def all_scratch_resources
  scratch_resources[:all] ||= []
end

#all_search_paramsObject



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/us_core_test_kit/search_test.rb', line 26

def all_search_params
  @all_search_params ||=
    patient_id_list.each_with_object({}) do |patient_id, params|
      params[patient_id] ||= []
      new_params =
        if fixed_value_search?
          fixed_value_search_param_values.map { |value| fixed_value_search_params(value, patient_id) }
        else
          [search_params_with_values(patient_id)]
        end
      new_params.reject! do |params|
        params.any? { |_key, value| value.blank? }
      end

      params[patient_id].concat(new_params)
    end
end

#all_search_params_present?(params) ⇒ Boolean

Returns:

  • (Boolean)


456
457
458
# File 'lib/us_core_test_kit/search_test.rb', line 456

def all_search_params_present?(params)
  params.all? { |_name, value| value.present? }
end

#all_search_variants_tested?Boolean

Returns:

  • (Boolean)


184
185
186
187
# File 'lib/us_core_test_kit/search_test.rb', line 184

def all_search_variants_tested?
  search_variant_test_records.all? { |_variant, tested| tested.present? } &&
    all_comparator_searches_tested?
end

#any_valid_search_params?(search_params) ⇒ Boolean

Returns:

  • (Boolean)


51
52
53
# File 'lib/us_core_test_kit/search_test.rb', line 51

def any_valid_search_params?(search_params)
  search_params.any? { |_patient_id, params| params.present? }
end

#array_of_codes(array) ⇒ Object



460
461
462
# File 'lib/us_core_test_kit/search_test.rb', line 460

def array_of_codes(array)
  array.map { |name| "`#{name}`" }.join(', ')
end

#cant_resolve_next_bundle_message(link) ⇒ Object



519
520
521
# File 'lib/us_core_test_kit/search_test.rb', line 519

def cant_resolve_next_bundle_message(link)
  "Could not resolve next bundle: #{link}"
end

#check_resource_against_params(resource, params) ⇒ Object

RESULT CHECKING ####



605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/us_core_test_kit/search_test.rb', line 605

def check_resource_against_params(resource, params)
  params.each do |name, search_value|
    paths = search_param_paths(name)

    match_found = false
    values_found = []

    paths.each do |path|
      type = .search_definitions[name.to_sym][:type]
      values_found =
        resolve_path(resource, path)
          .map do |value|
            if value.is_a? FHIR::Reference
              value.reference
            else
              value
            end
          end

      match_found =
        case type
        when 'Period', 'date', 'instant', 'dateTime'
          values_found.any? { |date| validate_date_search(search_value, date) }
        when 'HumanName'
          # When a string search parameter refers to the types HumanName and Address,
          # the search covers the elements of type string, and does not cover elements such as use and period
          # https://www.hl7.org/fhir/search.html#string
          search_value_downcase = search_value.downcase
          values_found.any? do |name|
            name&.text&.downcase&.start_with?(search_value_downcase) ||
              name&.family&.downcase&.start_with?(search_value_downcase) ||
              name&.given&.any? { |given| given.downcase.start_with?(search_value_downcase) } ||
              name&.prefix&.any? { |prefix| prefix.downcase.start_with?(search_value_downcase) } ||
              name&.suffix&.any? { |suffix| suffix.downcase.start_with?(search_value_downcase) }
          end
        when 'Address'
          search_value_downcase = search_value.downcase
          values_found.any? do |address|
            address&.text&.downcase&.start_with?(search_value_downcase) ||
            address&.city&.downcase&.start_with?(search_value_downcase) ||
            address&.state&.downcase&.start_with?(search_value_downcase) ||
            address&.postalCode&.downcase&.start_with?(search_value_downcase) ||
            address&.country&.downcase&.start_with?(search_value_downcase)
          end
        when 'CodeableConcept'
          # FHIR token search (https://www.hl7.org/fhir/search.html#token): "When in doubt, servers SHOULD 
          # treat tokens in a case-insensitive manner, on the grounds that including undesired data has 
          # less safety implications than excluding desired behavior". 
          codings = values_found.flat_map(&:coding)
          if search_value.include? '|'
            system = search_value.split('|').first
            code = search_value.split('|').last
            codings&.any? { |coding| coding.system == system && coding.code&.casecmp?(code) }
          else
            codings&.any? { |coding| coding.code&.casecmp?(search_value) }
          end
        when 'Coding'
          if search_value.include? '|'
            system = search_value.split('|').first
            code = search_value.split('|').last
            values_found.any? { |coding| coding.system == system && coding.code&.casecmp?(code) }
          else
            values_found.any? { |coding| coding.code&.casecmp?(search_value) }
          end
        when 'Identifier'
          if search_value.include? '|'
            values_found.any? { |identifier| "#{identifier.system}|#{identifier.value}" == search_value }
          else
            values_found.any? { |identifier| identifier.value == search_value }
          end
        when 'string'
          searched_values = search_value.downcase.split(/(?<!\\\\),/).map{ |string| string.gsub('\\,', ',') }
          values_found.any? do |value_found|
            searched_values.any? { |searched_value| value_found.downcase.starts_with? searched_value }
          end
        else
          # searching by patient requires special case because we are searching by a resource identifier
          # references can also be URLs, so we may need to resolve those URLs
          if ['subject', 'patient'].include? name.to_s
            id = search_value.split('Patient/').last
            possible_values = [id, "Patient/#{id}", "#{url}/Patient/#{id}"]
            values_found.any? do |reference|
              possible_values.include? reference
            end
          else
            search_values = search_value.split(/(?<!\\\\),/).map { |string| string.gsub('\\,', ',') }
            values_found.any? { |value_found| search_values.include? value_found }
          end
        end
      
      break if match_found
    end

    assert match_found,
           "#{resource_type}/#{resource.id} did not match the search parameters:\n" \
           "* Expected: #{search_value}\n" \
           "* Found: #{values_found.map(&:inspect).join(', ')}"
  end
end

#check_search_responseObject



164
165
166
167
168
# File 'lib/us_core_test_kit/search_test.rb', line 164

def check_search_response
  assert_response_status(200)
  assert_resource_type(:bundle)
  # NOTE: how do we want to handle validating Bundles?
end

#date_comparator_value(comparator, date) ⇒ Object



195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/us_core_test_kit/search_test.rb', line 195

def date_comparator_value(comparator, date)
  date = date.start || date.end if date.is_a? FHIR::Period
  case comparator
  when 'lt', 'le'
    comparator + (DateTime.xmlschema(date) + 1).xmlschema
  when 'gt', 'ge'
    comparator + (DateTime.xmlschema(date) - 1).xmlschema
  else
    # ''
    raise "Unsupported comparator '#{comparator}'"
  end
end

#default_search_values(param_name) ⇒ Object



307
308
309
310
311
312
# File 'lib/us_core_test_kit/search_test.rb', line 307

def default_search_values(param_name)
  definition = .search_definitions[param_name]
  return [] if definition.blank?

  definition[:multiple_or] == 'SHALL' ? [definition[:values].join(',')] : [definition[:values]]
end

#empty_search_params_message(empty_search_params) ⇒ Object



468
469
470
# File 'lib/us_core_test_kit/search_test.rb', line 468

def empty_search_params_message(empty_search_params)
  "Could not find values for the search parameters #{array_of_codes(empty_search_params.keys)}"
end

#fetch_all_bundled_resources(reply_handler: nil, max_pages: 20, additional_resource_types: [], resource_type: self.resource_type) ⇒ Object



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/us_core_test_kit/search_test.rb', line 477

def fetch_all_bundled_resources(
      reply_handler: nil,
      max_pages: 20,
      additional_resource_types: [],
      resource_type: self.resource_type
    )
  page_count = 1
  resources = []
  bundle = resource

  until bundle.nil? || page_count == max_pages
    resources += bundle&.entry&.map { |entry| entry&.resource }
    next_bundle_link = bundle&.link&.find { |link| link.relation == 'next' }&.url
    reply_handler&.call(response)

    break if next_bundle_link.blank?

    reply = fhir_client.raw_read_url(next_bundle_link)

    store_request('outgoing') { reply }
    error_message = cant_resolve_next_bundle_message(next_bundle_link)

    assert_response_status(200)
    assert_valid_json(reply.body, error_message)

    bundle = fhir_client.parse_reply(FHIR::Bundle, fhir_client.default_format, reply)

    page_count += 1
  end

  valid_resource_types = [resource_type, 'OperationOutcome'].concat(additional_resource_types)
  valid_resource_types << 'Medication' if resource_type == 'MedicationRequest'

  all_valid_resource_types =
    resources.all? { |entry| valid_resource_types.include? entry.resourceType }

  assert all_valid_resource_types,
         "All resources returned must be of the type: #{valid_resource_types.join(', ')}"

  resources
end

#filter_devices(resources) ⇒ Object



149
150
151
152
153
154
155
156
# File 'lib/us_core_test_kit/search_test.rb', line 149

def filter_devices(resources)
  codes_to_include = implantable_device_codes&.split(',')&.map(&:strip)
  return resources if codes_to_include.blank?

  resources.select! do |resource|
    resource&.type&.coding&.any? { |coding| codes_to_include.include?(coding.code) }
  end
end

#fixed_value_search_param_nameObject



412
413
414
# File 'lib/us_core_test_kit/search_test.rb', line 412

def fixed_value_search_param_name
  (search_param_names - ['patient']).first
end

#fixed_value_search_param_valuesObject



416
417
418
# File 'lib/us_core_test_kit/search_test.rb', line 416

def fixed_value_search_param_values
  .search_definitions[fixed_value_search_param_name.to_sym][:values]
end

#fixed_value_search_params(value, patient_id) ⇒ Object



420
421
422
423
424
# File 'lib/us_core_test_kit/search_test.rb', line 420

def fixed_value_search_params(value, patient_id)
  search_param_names.each_with_object({}) do |name, params|
    patient_id_param?(name) ? params[name] = patient_id : params[name] = value
  end
end

#initial_search_variant_test_recordsObject



174
175
176
177
178
179
180
181
182
# File 'lib/us_core_test_kit/search_test.rb', line 174

def initial_search_variant_test_records
  {}.tap do |records|
    records[:post_variant] = false if test_post_search?
    records[:medication_inclusion] = false if test_medication_inclusion?
    records[:reference_variants] = false if test_reference_variants?
    records[:token_variants] = false if token_search_params.present?
    records[:comparator_searches] = Set.new if params_with_comparators.present?
  end
end

#no_resources_skip_message(resource_type = self.resource_type) ⇒ Object



472
473
474
475
# File 'lib/us_core_test_kit/search_test.rb', line 472

def no_resources_skip_message(resource_type = self.resource_type)
  "No #{resource_type} resources appear to be available. " \
  "Please use patients with more information"
end

#patient_id_listObject



433
434
435
436
437
# File 'lib/us_core_test_kit/search_test.rb', line 433

def patient_id_list
  return [nil] unless respond_to? :patient_ids

  patient_ids.split(',').map(&:strip)
end

#patient_id_param?(name) ⇒ Boolean

Returns:

  • (Boolean)


443
444
445
# File 'lib/us_core_test_kit/search_test.rb', line 443

def patient_id_param?(name)
  name == 'patient' || (name == '_id' && resource_type == 'Patient')
end

#patient_search?Boolean

Returns:

  • (Boolean)


439
440
441
# File 'lib/us_core_test_kit/search_test.rb', line 439

def patient_search?
  search_param_names.any? { |name| patient_id_param? name }
end

#perform_comparator_searches(params, patient_id) ⇒ Object



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/us_core_test_kit/search_test.rb', line 217

def perform_comparator_searches(params, patient_id)
  params_with_comparators.each do |name|
    next if search_variant_test_records[:comparator_searches].include? name

    required_comparators(name).each do |comparator|
      paths = search_param_paths(name).first
      date_element = find_a_value_at(scratch_resources_for_patient(patient_id), paths)
      params_with_comparator = params.merge(name => date_comparator_value(comparator, date_element))

      search_and_check_response(params_with_comparator)

      fetch_all_bundled_resources
        .each { |resource| check_resource_against_params(resource, params_with_comparator) }
    end

    search_variant_test_records[:comparator_searches] << name
  end
end

#perform_multiple_or_search_testObject



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/us_core_test_kit/search_test.rb', line 315

def perform_multiple_or_search_test
  resolved_one = false

  all_search_params.each do |patient_id, params_list|
    next unless params_list.present?
    
    search_params = params_list.first
    existing_values = {}
    missing_values = {}

    multiple_or_search_params.each do |param_name|
      search_value = default_search_values(param_name.to_sym)
      search_params = search_params.merge("#{param_name}" => search_value)
      existing_values[param_name.to_sym] = scratch_resources_for_patient(patient_id).map(&param_name.to_sym).compact.uniq
    end

    # skip patient without multiple-or values
    next if existing_values.values.any?(&:empty?)

    resolved_one = true

    search_and_check_response(search_params)

    resources_returned =
      fetch_all_bundled_resources
        .select { |resource| resource.resourceType == resource_type }

    multiple_or_search_params.each do |param_name|
      missing_values[param_name.to_sym] = existing_values[param_name.to_sym] - resources_returned.map(&param_name.to_sym)
    end

    missing_value_message = missing_values
      .reject { |_param_name, missing_value| missing_value.empty? }
      .map { |param_name, missing_value| "#{missing_value.join(',')} values from #{param_name}" }
      .join(' and ')

    assert missing_value_message.blank?, "Could not find #{missing_value_message} in any of the resources returned for Patient/#{patient_id}"

    break if resolved_one
  end
end

#perform_post_search(get_search_resources, params) ⇒ Object



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/us_core_test_kit/search_test.rb', line 132

def perform_post_search(get_search_resources, params)
  fhir_search resource_type, params: params, search_method: :post

  check_search_response

  post_search_resources = fetch_all_bundled_resources.select { |resource| resource.resourceType == resource_type }
  get_resource_count = get_search_resources.length
  post_resource_count = post_search_resources.length

  search_variant_test_records[:post_variant] = true

  assert get_resource_count == post_resource_count,
         "Expected search by POST to return the same results as search by GET, " \
         "but GET search returned #{get_resource_count} resources, and POST search " \
         "returned #{post_resource_count} resources."
end

#perform_reference_with_type_search(params, resource_count) ⇒ Object



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/us_core_test_kit/search_test.rb', line 236

def perform_reference_with_type_search(params, resource_count)
  return if resource_count == 0
  return if search_variant_test_records[:reference_variants]

  new_search_params = params.merge('patient' => "Patient/#{params['patient']}")
  search_and_check_response(new_search_params)

  new_resource_count =
    fetch_all_bundled_resources
      .select { |resource| resource.resourceType == resource_type }
      .count

  assert new_resource_count == resource_count,
         "Expected search by `#{params['patient']}` to to return the same results as searching " \
         "by `#{new_search_params['patient']}`, but found #{resource_count} resources with " \
         "`#{params['patient']}` and #{new_resource_count} with `#{new_search_params['patient']}`"

  search_variant_test_records[:reference_variants] = true
end

#perform_search(params, patient_id) ⇒ Object



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/us_core_test_kit/search_test.rb', line 95

def perform_search(params, patient_id)
  fhir_search resource_type, params: params

  perform_search_with_status(params, patient_id) if response[:status] == 400 && possible_status_search?

  check_search_response

  resources_returned =
    fetch_all_bundled_resources.select { |resource| resource.resourceType == resource_type }

  return [] if resources_returned.blank?

  perform_comparator_searches(params, patient_id) if params_with_comparators.present?

  filter_devices(resources_returned) if resource_type == 'Device'

  if first_search?
    all_scratch_resources.concat(resources_returned).uniq!
    scratch_resources_for_patient(patient_id).concat(resources_returned).uniq!
  end

  resources_returned.each do |resource|
    check_resource_against_params(resource, params)
  end

  save_delayed_references(resources_returned) if saves_delayed_references?

  return resources_returned if all_search_variants_tested?

  perform_post_search(resources_returned, params) if test_post_search?
  test_medication_inclusion(resources_returned, params, patient_id) if test_medication_inclusion?
  perform_reference_with_type_search(params, resources_returned.count) if test_reference_variants?
  perform_search_with_system(params, patient_id) if token_search_params.present?

  resources_returned
end

#perform_search_with_status(original_params, patient_id, status_search_values: self.status_search_values, resource_type: self.resource_type) ⇒ Object



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/us_core_test_kit/search_test.rb', line 276

def perform_search_with_status(
      original_params,
      patient_id,
      status_search_values: self.status_search_values,
      resource_type: self.resource_type
    )
  assert resource.is_a?(FHIR::OperationOutcome), "Server returned a status of 400 without an OperationOutcome"
  # TODO: warn about documenting status requirements
  status_search_values.flat_map do |status_value|
    search_params = original_params.merge("#{status_search_param_name}": status_value)

    search_and_check_response(search_params)

    entries = resource.entry.select { |entry| entry.resource.resourceType == resource_type }

    if entries.present?
      original_params.merge!("#{status_search_param_name}": status_value)
      break
    end
  end
end

#perform_search_with_system(params, patient_id) ⇒ Object



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/us_core_test_kit/search_test.rb', line 256

def perform_search_with_system(params, patient_id)
  return if search_variant_test_records[:token_variants]

  new_search_params = token_search_params.each_with_object({}) do |name, search_params|
    search_params[name] = search_param_value(name, patient_id, include_system: true)
  end
  return if new_search_params.any? { |_name, value| value.blank? }

  search_params = params.merge(new_search_params)
  search_and_check_response(search_params)

  resources_returned =
    fetch_all_bundled_resources
      .select { |resource| resource.resourceType == resource_type }

  assert resources_returned.present?, "No resources were returned when searching by `system|code`"

  search_variant_test_records[:token_variants] = true
end

#references_to_save(resource_type = nil) ⇒ Object



407
408
409
410
# File 'lib/us_core_test_kit/search_test.rb', line 407

def references_to_save(resource_type = nil)
   = resource_type == 'Provenance' ?  : 
  .delayed_references
end

#required_comparators(name) ⇒ Object



208
209
210
211
212
213
214
215
# File 'lib/us_core_test_kit/search_test.rb', line 208

def required_comparators(name)
  
    .search_definitions
    .dig(name.to_sym, :comparators)
    .select { |_comparator, expectation| expectation == 'SHALL' }
    .keys
    .map(&:to_s)
end

#run_provenance_revinclude_search_testObject



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/us_core_test_kit/search_test.rb', line 55

def run_provenance_revinclude_search_test
  # TODO: skip if not supported?
  skip_if !any_valid_search_params?(all_provenance_revinclude_search_params), unable_to_resolve_params_message

  provenance_resources =
    all_provenance_revinclude_search_params.flat_map do |_patient_id, params_list|
      params_list.flat_map do |params|
        fhir_search resource_type, params: params

        perform_search_with_status(params, patient_id) if response[:status] == 400 && possible_status_search?

        check_search_response

        fetch_all_bundled_resources(additional_resource_types: ['Provenance'])
          .select { |resource| resource.resourceType == 'Provenance' }
      end
    end

  scratch_provenance_resources[:all] ||= []
  scratch_provenance_resources[:all].concat(provenance_resources)

  save_delayed_references(provenance_resources, 'Provenance')

  skip_if provenance_resources.empty?, no_resources_skip_message('Provenance')
end

#run_search_testObject



81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/us_core_test_kit/search_test.rb', line 81

def run_search_test
  # TODO: skip if not supported?
  skip_if !any_valid_search_params?(all_search_params), unable_to_resolve_params_message

  resources_returned =
    all_search_params.flat_map do |patient_id, params_list|
      params_list.flat_map { |params| perform_search(params, patient_id) }
    end

  skip_if resources_returned.empty?, no_resources_skip_message

  perform_multiple_or_search_test if multiple_or_search_params.present?
end

#save_delayed_references(resources, containing_resource_type = self.resource_type) ⇒ Object



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/us_core_test_kit/search_test.rb', line 587

def save_delayed_references(resources, containing_resource_type = self.resource_type)
  resources.each do |resource|
    references_to_save(containing_resource_type).each do |reference_to_save|
      resolve_path(resource, reference_to_save[:path])
        .select { |reference| reference.is_a?(FHIR::Reference) && !reference.contained? }
        .each do |reference|
          resource_type = reference.resource_class.name.demodulize
          need_to_save = reference_to_save[:resources].include?(resource_type)
          next unless need_to_save

          save_resource_reference(resource_type, reference)
        end
    end
  end
end

#save_resource_reference(resource_type, reference) ⇒ Object



581
582
583
584
585
# File 'lib/us_core_test_kit/search_test.rb', line 581

def save_resource_reference(resource_type, reference)
  scratch[:references] ||= {}
  scratch[:references][resource_type] ||= Set.new
  scratch[:references][resource_type] << reference
end

#scratch_resources_for_patient(patient_id) ⇒ Object



401
402
403
404
405
# File 'lib/us_core_test_kit/search_test.rb', line 401

def scratch_resources_for_patient(patient_id)
  return all_scratch_resources if patient_id.nil?

  scratch_resources[patient_id] ||= []
end

#search_and_check_response(params, resource_type = self.resource_type) ⇒ Object



158
159
160
161
162
# File 'lib/us_core_test_kit/search_test.rb', line 158

def search_and_check_response(params, resource_type = self.resource_type)
  fhir_search resource_type, params: params

  check_search_response
end

#search_param_paths(name) ⇒ Object



447
448
449
450
451
452
453
454
# File 'lib/us_core_test_kit/search_test.rb', line 447

def search_param_paths(name)
  paths = .search_definitions[name.to_sym][:paths]
  if paths.first =='class' 
    paths[0] = 'local_class'
  end
  
  paths
end

#search_param_value(name, patient_id, include_system: false) ⇒ Object



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/us_core_test_kit/search_test.rb', line 523

def search_param_value(name, patient_id, include_system: false)
  paths = search_param_paths(name)
  search_value = nil
  paths.each do |path|
    element = find_a_value_at(scratch_resources_for_patient(patient_id), path)

    search_value =
      case element
      when FHIR::Period
        if element.start.present?
          'gt' + (DateTime.xmlschema(element.start) - 1).xmlschema
        else
          end_datetime = get_fhir_datetime_range(element.end)[:end]
          'lt' + (end_datetime + 1).xmlschema
        end
      when FHIR::Reference
        element.reference
      when FHIR::CodeableConcept
        if include_system
          coding =
            find_a_value_at(element, 'coding') { |coding| coding.code.present? && coding.system.present? }
          coding.present? ? "#{coding.system}|#{coding.code}" : nil
        else
          find_a_value_at(element, 'coding.code')
        end
      when FHIR::Identifier
        if include_system
          identifier = find_a_value_at(scratch_resources_for_patient(patient_id), path) do |identifier|
            identifier.value.present? && identifier.system.present?
          end
          identifier.present? ? "#{identifier.system}|#{identifier.value}" : nil
        else
          element.value
        end
      when FHIR::Coding
        if include_system
          coding = find_a_value_at(scratch_resources_for_patient(patient_id), path) do |coding|
            coding.code.present? && coding.system.present?
          end
          coding.present? ? "#{coding.system}|#{coding.code}" : nil
        else
          element.code
        end
      when FHIR::HumanName
        element.family || element.given&.first || element.text
      when FHIR::Address
        element.text || element.city || element.state || element.postalCode || element.country
      else
        element
      end

      break if search_value.present?
  end

  escaped_value = search_value&.gsub(',', '\\,')
  escaped_value
end

#search_params_with_values(patient_id) ⇒ Object



426
427
428
429
430
431
# File 'lib/us_core_test_kit/search_test.rb', line 426

def search_params_with_values(patient_id)
  search_param_names.each_with_object({}) do |name, params|
    value = patient_id_param?(name) ? patient_id : search_param_value(name, patient_id)
    params[name] = value
  end
end

#search_variant_test_recordsObject



170
171
172
# File 'lib/us_core_test_kit/search_test.rb', line 170

def search_variant_test_records
  @search_variant_test_records ||= initial_search_variant_test_records
end

#status_search_param_nameObject



298
299
300
301
# File 'lib/us_core_test_kit/search_test.rb', line 298

def status_search_param_name
  @status_search_param_name ||=
    .search_definitions.keys.find { |key| key.to_s.include? 'status' }
end

#status_search_valuesObject



303
304
305
# File 'lib/us_core_test_kit/search_test.rb', line 303

def status_search_values
  default_search_values(status_search_param_name)
end

#test_medication_inclusion(medication_requests, params, patient_id) ⇒ Object



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/us_core_test_kit/search_test.rb', line 357

def test_medication_inclusion(medication_requests, params, patient_id)
  return if search_variant_test_records[:medication_inclusion]

  scratch[:medication_resources] ||= {}
  scratch[:medication_resources][:all] ||= []
  scratch[:medication_resources][patient_id] ||= []
  scratch[:medication_resources][:contained] ||= []

  requests_with_external_references =
    medication_requests
      .select { |request| request&.medicationReference&.present? }
      .reject { |request| request&.medicationReference&.reference&.start_with? '#' }

  contained_medications =
    medication_requests
      .select { |request| request&.medicationReference&.reference&.start_with? '#' }
      .flat_map(&:contained)
      .select { |resource| resource.resourceType == 'Medication' }

  scratch[:medication_resources][:all] += contained_medications
  scratch[:medication_resources][patient_id] += contained_medications
  scratch[:medication_resources][:contained] += contained_medications

  return if requests_with_external_references.blank?

  search_params = params.merge(_include: 'MedicationRequest:medication')

  search_and_check_response(search_params)

  medications = fetch_all_bundled_resources.select { |resource| resource.resourceType == 'Medication' }
  assert medications.present?, 'No Medications were included in the search results'

  medications.uniq!(&:id)

  scratch[:medication_resources][:all] += medications
  scratch[:medication_resources][patient_id] += medications

  search_variant_test_records[:medication_inclusion] = true
end

#unable_to_resolve_params_messageObject



464
465
466
# File 'lib/us_core_test_kit/search_test.rb', line 464

def unable_to_resolve_params_message
  "Could not find values for all search params #{array_of_codes(search_param_names)}"
end